@@ -1,12 +1,11 @@
 from themispy.project.utils import (
     PROJECT_PATH, PROJECT_TITLE, 
-    build_path, split_url, get_files
+    build_path, split_filepath
 )
 
 __all__ = [
     "PROJECT_PATH",
     "PROJECT_TITLE",
     "build_path",
-    "split_url",
-    "get_files"
+    "split_filepath"
 ]
